lapd: Reduce N200 (SABM retransmission count)

N200, which controls the maxium number of LAPD retransmissions,
is set to 300. This will cause a long waiting time until
LAPD detects a failed link. This commit reduces the retransmission
count to 50 in order to get a faster link re-establishment in
case of link failure. This patch will only affect the ericsson
LAPD profile, all other lapd profiles will not be touched.

Change-Id: I4f56f9d00520adc0c0a4497547762cd054030867
diff --git a/src/input/lapd.c b/src/input/lapd.c
index f5909b4..370697d 100644
--- a/src/input/lapd.c
+++ b/src/input/lapd.c
@@ -101,12 +101,12 @@
  * periodically scanning through all timeslots to find the timeslot
  * where the bsc is transmitting its sabm frames the normal maximum
  * retransmission (n200) of 3 is not enough. In order not to miss
  * the bts, n200 has been increased to 300, which is an educated
  * guess. */
 
 const struct lapd_profile lapd_profile_abis_ericsson = {
 	.k		= LAPD_SET_K(2,1),
-	.n200		= 300,
+	.n200		= 50,
 	.n201		= 260,
 	.n202		= 0, /* infinite */
 	.t200_sec	= 0,	.t200_usec	= 300000,
@@ -101,12 +101,12 @@
  * where the bsc is transmitting its sabm frames the normal maximum
  * retransmission (n200) of 3 is not enough. In order not to miss
- * the bts, n200 has been increased to 300, which is an educated
+ * the bts, n200 has been increased to 50, which is an educated
  * guess. */
 